@@ -45,10 +45,6 @@
 
 typedef void*( mod_gm_worker_fn)(gearman_job_st *job, void *context, size_t *result_size, gearman_return_t *ret_ptr);
 
-gearman_client_st *current_client;
-gearman_client_st *current_client_dup;
-gearman_job_st *current_gearman_job;
-
 int create_client( gm_server_t * server_list[GM_LISTSIZE], gearman_client_st * client);
 int create_worker( gm_server_t * server_list[GM_LISTSIZE], gearman_worker_st * worker);
 int add_job_to_queue( gearman_client_st *client, gm_server_t * server_list[GM_LISTSIZE], char * queue, char * uniq, char * data, int priority, int retries, int transport_mode);
