@@ -33,8 +33,16 @@
 #define BROKER_MODULE "mod_gearman_naemon.o"
 #endif
 
+#include "common.h"
 #include <worker_dummy_functions.c>
 
+#include <libgearman/gearman.h>
+
+mod_gm_opt_t *mod_gm_opt;
+char hostname[GM_SMALLBUFSIZE];
+gearman_client_st *current_client;
+gearman_client_st *current_client_dup;
+
 int service_check_timeout;
 int host_check_timeout;
 int currently_running_service_checks;
