@@ -14,6 +14,8 @@
 #include <worker_dummy_functions.c>
 
 mod_gm_opt_t *mod_gm_opt;
+char hostname[GM_SMALLBUFSIZE];
+volatile sig_atomic_t shmid;
 
 char* my_tmpfile(void);
 char* my_tmpfile() {
